@@ -3,7 +3,7 @@ use base 'Catalyst::Base';
 
 
 
-our $VERSION = 0.0101;
+our $VERSION = 0.03;
 
 
 
@@ -300,8 +300,9 @@ Add crud configuration:
                 optional => [ __PACKAGE__->columns ],
                 required => [ qw/ title format genre /],
                 constraint_methods => {
-                    isbn => { name => "fv_isbn", constraint => qr/^[\d-]$/ },
+                    isbn => { name => "fv_isbn", constraint => qr/^[\d-]+$/ },
                 },
+                missing_optional_valid => 1,
                 msgs => {
                     format => '%s',
                     constraints => {
@@ -384,6 +385,7 @@ Edit the root/base/header.tt and add this inside the content div:
                     url => FV_URI(),
                     email => Data::FormValidator::Constraints::email(),
                 },
+                missing_optional_valid => 1,
                 msgs => {
                     format => '%s',
                     constraints => {
