@@ -19,17 +19,17 @@ Catalyst Controller.
 
 =head1 METHODS
 
-=head2 begin
+=head2 model_class
 
-Set up the default model and class for this Controller
+Define the  model class for this Controller
 
 =cut
-sub begin : Private {
-    my ($self, $c) = @_;
-    $self->set_model_class($c, "BookShelf::Model::BookShelfDB::Genre");
+sub model_class {
+    return("BookShelf::Model::BookShelfDB::Genre");
 }
 
 
+
 =head1 AUTHOR
 
 A clever guy
